import 'package:dio/dio.dart';
import 'package:risecx_chat_client/models/models.dart';
import 'package:risecx_chat_client/repositories/repository_base.dart';

class ChatRepository {
  Future<ChatHistortModel> getHistory(UserModel user) async {
    try {
      final Map<String, dynamic> data = new Map<String, dynamic>();
      data['user'] = user.id;
      final Response response = await RespositoryBase.instance.client
          .post('/webchat/history', data: data);
      return ChatHistortModel.fromJson(response.data);
    } on DioError catch (e) {
      throw e.message;
    }
  }

  dynamic getFavorites(UserModel user) async {
    try {
      final Response response = await RespositoryBase.instance.client
          .get('/webchat/history/favorites/${user.id}');
      return response.data;
    } on DioError catch (e) {
      print(e.message);
      throw Exception(e);
    }
  }

  dynamic getPrograms(UserModel user) async {
    try {
      final Response response =
          await RespositoryBase.instance.client.get('/programs');
      return response.data;
    } on DioError catch (e) {
      print(e.message);
      throw Exception(e);
    }
  }

  dynamic getQuickMenu() async {
    try {
      final Response response =
          await RespositoryBase.instance.client.get('/settings/quick-menu');
      return response.data;
    } on DioError catch (e) {
      throw Exception(e);
    }
  }

  dynamic addOrRemoveFavoriteMessage(message, bool favorite) async {
    try {
      var messageId = message["_id"];
      final Map<String, dynamic> data = new Map<String, dynamic>();
      data['favorite'] = favorite.toString();
      final Response response = await RespositoryBase.instance.client
          .put('/webchat/history/favorites/$messageId', data: data);
      return response.data;
    } on DioError catch (e) {
      throw Exception(e);
    }
  }

  dynamic subscribeUnsubscribe(ProgramModel program, UserModel user) async {
    try {
      final Response response = await RespositoryBase.instance.client
          .post('/programs/${program.sId}/subscribe', data: {"_id": user.sId});
      return response.data;
    } on DioError catch (e) {
      throw Exception(e);
    } catch (e) {
      throw e;
    }
  }

//ANALYTICS CALL
  void eventCounterReport(dynamic data) async {
    await RespositoryBase.instance.client
        .post('/sessions-event-counter', data: data);
  }
}
