import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:risecx_chat_client/blocs/blocs.dart';

class ActionButtons extends StatefulWidget {
  final Function onFavoriteButtonPress;
  final Function onMenuItemSelect;
  final ChatBloc chatBloc;
  const ActionButtons(
      {Key key,
      this.onFavoriteButtonPress,
      this.onMenuItemSelect,
      @required this.chatBloc})
      : super(key: key);
  @override
  _ActionButtonsState createState() => _ActionButtonsState();
}

class _ActionButtonsState extends State<ActionButtons> {
  @override
  Widget build(BuildContext context) {
    return StreamBuilder(
        stream: widget.chatBloc.selecteMessagesToggleStream,
        builder: (BuildContext context, AsyncSnapshot snapshot) {
          if (snapshot.data != null && snapshot.data.length > 0) {
            return actionButtonsWidget(snapshot.data);
          } else {
            return widget.onMenuItemSelect != null ? menu() : IgnorePointer();
          }
        });
  }

  Widget actionButtonsWidget(dynamic selectedMessage) {
    return Column(
      children: <Widget>[
        FlatButton(
          child: Icon(
            Icons.star,
            color: Colors.white,
          ),
          onPressed: () {
            if (widget.onFavoriteButtonPress != null)
              widget.onFavoriteButtonPress(selectedMessage);
          },
        )
      ],
    );
  }

  Widget menu() {
    return PopupMenuButton(
      onSelected: _onMenuItemSelectHandler,
      itemBuilder: (BuildContext context) {
        return MenuItems.choices.map((String choice) {
          return PopupMenuItem<String>(
            value: choice,
            child: Text(choice),
          );
        }).toList();
      },
    );
  }

  void _onMenuItemSelectHandler(selected) {
    widget.onMenuItemSelect(selected);
  }
}

class MenuItems {
  static const String FAVORITES = 'Favorites';
  static const String ABOUT = 'About';
  static const String LOGOUT = 'Logout';
  static const String WEBVIEWER = 'WebViewer Test';
  static const List<String> choices = <String>[FAVORITES, LOGOUT];
}
