import 'package:flutter/material.dart';
import 'package:risecx_chat_client/blocs/blocs.dart';
import 'package:risecx_chat_client/models/user_model.dart';
import 'package:risecx_chat_client/widgets/chat/action-bar.dart';
import 'package:risecx_chat_client/widgets/commons/empty_warning_widget.dart';
import 'package:risecx_chat_client/widgets/widgets.dart';

class FavoriteWidgets extends StatefulWidget {
  final ChatBloc bloc;
  final UserModel user;
  final Function onPayloadPress;
  FavoriteWidgets(this.bloc, this.user, {this.onPayloadPress});

  @override
  _FavoriteWidgetsState createState() => _FavoriteWidgetsState();
}

class _FavoriteWidgetsState extends State<FavoriteWidgets>
    with AutomaticKeepAliveClientMixin {
  @override
  void initState() {
    super.initState();
    this.widget.bloc.getFavoriteMessages(this.widget.user);
  }

  void _onUnfavorite(selectedMessage) {
    widget.bloc.addOrRemoveFavoriteMessage(selectedMessage, false);
  }

  @override
  Widget build(BuildContext context) {
    return Column(children: <Widget>[
      Expanded(
          child: Stack(children: [
        Container(
          child: StreamBuilder(
            stream: this.widget.bloc.favoriteMessagesListStream,
            builder: (BuildContext context, AsyncSnapshot snapshot) {
              Widget _widget = IgnorePointer();
              if (snapshot.hasData) {
                if (snapshot.data.length > 0) {
                  _widget = ListView.builder(
                    itemCount: snapshot.data.length,
                    itemBuilder: (context, index) => MessageItem(
                      chatBloc: widget.bloc,
                      message: snapshot.data[index]['message'],
                      onPayloadPress: widget.onPayloadPress,
                    ),
                  );
                } else {
                  _widget = EmptyWarningWidget(
                    Icons.star,
                    message: 'No Favorite Messages Yet',
                  );
                }
              }
              return _widget;
            },
          ),
        ),
        Positioned(
            child: Container(
                height: 56,
                child: ActionBar(
                  bloc: widget.bloc,
                  actions: <ActionBarButton>[
                    ActionBarButton(
                        icon: Icon(Icons.star_border), onPressed: _onUnfavorite)
                  ],
                ))),
      ]))
    ]);
  }

  @override
  bool get wantKeepAlive => true;
}
