import 'package:flutter/material.dart';
import 'package:risecx_chat_client/blocs/blocs.dart';
import 'package:risecx_chat_client/models/models.dart';

class MessageInput extends StatefulWidget {
  final TextEditingController textEditingController;
  final Function onPressed;
  final ChatBloc chatBloc;
  final Function onQuickMenuSelect;
  MessageInput(
      {@required this.textEditingController,
      this.onPressed,
      this.onQuickMenuSelect,
      @required this.chatBloc});

  @override
  _MessageInputState createState() => _MessageInputState();
}

class _MessageInputState extends State<MessageInput> {
  @override
  void initState() {
    super.initState();
    widget.chatBloc.getQuickMenuItems();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      color: Color(0xFFEFF3F7),
      child: Row(
        mainAxisSize: MainAxisSize.min,
        children: <Widget>[
          SizedBox(width: 6),
          Flexible(
            child: IconButton(
              color: Color(0xFFd4d5d9),
              disabledColor: Theme.of(context).primaryColorDark,
              icon: Icon(Icons.menu),
              onPressed: _quickMenuToggle,
            ),
          ),
          Flexible(
            flex: 9,
            child: TextField(
              controller: widget.textEditingController,
              decoration: InputDecoration(
                filled: true,
                fillColor: Color(0xFFEFF3F7),
                border: InputBorder.none,
                hintText: 'Send a message...',
                hintStyle: TextStyle(
                  color: Color(0xFFd4d5d9),
                ),
              ),
            ),
          ),
          Flexible(
            child: IconButton(
              color: Color(0xFFc4c5c9),
              disabledColor: Theme.of(context).primaryColorDark,
              icon: Icon(Icons.send),
              onPressed: widget.onPressed,
            ),
          ),
          SizedBox(width: 10),
        ],
      ),
    );
  }

  void _quickMenuToggle() {
    showModalBottomSheet<void>(
        context: context,
        builder: (BuildContext context) {
          return StreamBuilder(
              stream: widget.chatBloc.quickMenuListStream,
              builder: (BuildContext context, AsyncSnapshot snapshot) {
                Widget _widget = new ListTile(
                  leading: new Icon(Icons.list),
                  title: new Text('No quick messages registered yet'),
                  onTap: () {
                    Navigator.pop(context);
                  },
                );
                if (snapshot.hasData) {
                  _widget = new ListView(
                      //mainAxisSize: MainAxisSize.min,
                      children: menuItemsList(snapshot.data));
                }
                return _widget;
              });
        });
  }

  List<Widget> menuItemsList(List<QuickMenuItemModel> data) {
    List<ListTile> items = new List();
    data.forEach((d) {
      items.add(new ListTile(
        title: new Text(d.name),
        leading: new Icon(Icons.chevron_right),
        onTap: () {
          Navigator.pop(context);
          widget.onQuickMenuSelect(d);
        },
      ));
    });
    return items;
  }
}
