import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:risecx_chat_client/blocs/blocs.dart';

import 'messages_types/messages_types.dart';

class MessageItem extends StatefulWidget {
  final dynamic message;
  final Function onPayloadPress;
  final Function onMediaView;
  final ChatBloc chatBloc;
  MessageItem(
      {@required this.message,
      @required this.onPayloadPress,
      this.onMediaView,
      @required this.chatBloc});

  get _jsonMessage =>
      (this.message is String) ? jsonDecode(this.message) : this.message;

  @override
  _MessageItemState createState() => _MessageItemState();
}

class _MessageItemState extends State<MessageItem> {
  bool isSentMessage() =>
      widget._jsonMessage['author'] == "me" ||
      widget._jsonMessage['incoming_message'] != null;

  Alignment get _messageAlignment =>
      isSentMessage() ? Alignment.topLeft : Alignment.topRight;

  @override
  Widget build(BuildContext context) {
    return StreamBuilder(
        stream: widget.chatBloc.selecteMessagesToggleStream,
        builder: (BuildContext context, AsyncSnapshot snapshot) {
          return GestureDetector(
            child: Container(
              decoration:
                  BoxDecoration(color: getBackgroundColor(snapshot.data)),
              child: Align(
                  alignment: _messageAlignment,
                  child: isSentMessage()
                      ? SentMessageWidget(message: widget._jsonMessage)
                      : ReceivedMessageWidget(
                          message: widget._jsonMessage,
                          onPayloadPress: widget.onPayloadPress,
                          onMediaView: widget.onMediaView,
                        )),
            ),
            onLongPress: () {
              widget.chatBloc.selectMessageToggle(widget._jsonMessage);
            },
          );
        });
  }

  Color getBackgroundColor(dynamic selectedMessage) {
    if (selectedMessage != null && selectedMessage == widget._jsonMessage) {
      return Color.fromRGBO(189, 208, 235, 0.8);
    } else {
      return Colors.transparent;
    }
  }
}
