import 'package:flutter/material.dart';
import 'package:risecx_chat_client/widgets/chat/messages_types/messages_types.dart';

class MessageWidget extends StatelessWidget {
  final Map message;
  final Function onPayloadPress;
  final Function onMediaView;

  const MessageWidget(
      {Key key, this.message, this.onPayloadPress, this.onMediaView})
      : super(key: key);

  String get _messageType {
    if (message.containsKey('attachment') && message['attachment'] != null) {
      if (message['attachment']['type'] == 'image') return 'image';
      if (message['attachment']['kind'] == 'blocks-videos') return 'video';
      if (message['attachment']['type'] == 'template')
        return message['attachment']['payload']['template_type'];
    }

    if (message.containsKey('text') &&
        message.containsKey('quick_replies') &&
        message['quick_replies'] != null) return 'quickResponse';
    if (message.containsKey('text') &&
        message.containsKey('menus') &&
        message['menus'] != null) return 'menu';
    if ((message.containsKey('text') &&
            (!message.containsKey('quick_replies') ||
                message['quick_replies'] == null)) ||
        message.containsKey('payloadTitle') && message['payloadTitle'] != null)
      return 'text';
    else
      throw Exception('Unknown Message Type: $message');
  }

  Widget messageWidget() {
    try {
      final key = GlobalKey();
      switch (_messageType) {
        case 'text':
          return TextMessageWidget(key: key, message: this.message);
        case 'card':
          return Text('Card Message');
        case 'list':
          return ListMessageWidget(
            key: key,
            message: this.message,
            onPayloadPress: onPayloadPress,
          );
        case 'quickResponse':
          return QuickReplyMessageWidget(
            key: key,
            message: this.message,
            onPayloadPress: onPayloadPress,
          );
        case 'gallery':
          return Text('Gallery Message');
        case 'video':
          return VideoMessageWidget(
              key: key,
              message: this.message,
              onMediaView: onMediaView,
              onPayloadPress: onPayloadPress);
        case 'image':
          return ImageMessageWidget(key: key, message: this.message);
        case 'button':
          return ButtonMessageWidget(
            key: key,
            message: this.message,
            onPayloadPress: onPayloadPress,
          );
        case 'menu':
          return MenusMessageWidget(
            key: key,
            message: this.message,
            onPayloadPress: onPayloadPress,
          );
        case 'generic':
          return GenericMessageWidget(
            key: key,
            message: this.message,
            onPayloadPress: onPayloadPress,
          );
        default:
          return IgnorePointer();
      }
    } catch (e) {
      return IgnorePointer();
    }
  }

  @override
  Widget build(BuildContext context) {
    return messageWidget();
  }
}
